#include <cstdio>
#include <cmath>
#include <cstring>
#include <set>
#include <algorithm>
#include <utility>
using namespace std;

#define EPS 1e-9
#define LD long double
#define PII pair<int,int>
#define PDD pair<LD,LD>
#define PPII pair<PII,PII >
#define PPDD pair<PDD,PDD >
#define SP set<PPII >
#define X1 first.first
#define Y1 first.second
#define X2 second.first
#define Y2 second.second
#define DX(a) ((a).X2-(a).X1)
#define DY(a) ((a).Y2-(a).Y1)

bool load_lines(SP &lines) {
	int x = 0, y = 0;
	while (1) {
		char inst[42];
		int dx, dy;
		scanf("%s", inst);
		if (inst[0] == 'Q') return false;
		if (inst[0] == 'E') break;
		scanf("%d %d", &dx, &dy);
		if (inst[0] == 'L') {
			lines.insert(make_pair(
				make_pair(x,y),
				make_pair(x+dx, y+dy)
			));
		}
		x += dx;
		y += dy;
	}
	return true;
}

bool contains(PPII a, PII pnt) {
	if (pnt.first >= min(a.X1, a.X2) && pnt.first <= max(a.X1, a.X2)) {
		return (pnt.first - a.X1)*(a.Y2 - a.Y1) == (pnt.second - a.Y1)*(a.X2 - a.X1);
	}
	return false;
}

PPII join_adj(PPII a, PPII b) {
	if (DX(a)*DY(a) >= 0) {
		return make_pair(
			make_pair(min(min(a.X1, a.X2), min(b.X1, b.X2)),
			          min(min(a.Y1, a.Y2), min(b.Y1, b.Y2))),
			make_pair(max(max(a.X1, a.X2), max(b.X1, b.X2)),
			          max(max(a.Y1, a.Y2), max(b.Y1, b.Y2)))
		);
	} else {
		return make_pair(
			make_pair(min(min(a.X1, a.X2), min(b.X1, b.X2)),
			          max(max(a.Y1, a.Y2), max(b.Y1, b.Y2))),
			make_pair(max(max(a.X1, a.X2), max(b.X1, b.X2)),
			          min(min(a.Y1, a.Y2), min(b.Y1, b.Y2)))
		);
	}
}

bool is_adj(PPII a, PPII b) {
	PPII joined = join_adj(a, b);
	return contains(joined, a.first) && contains(joined, a.second)
	    && contains(joined, b.first) && contains(joined, b.second);
}

SP::iterator find_adj(SP &lines, PPII line) {
	for (SP::iterator it = lines.begin(); it != lines.end(); ++it) {
		if (is_adj(*it, line)) {
			return it;
		}
	}
	return lines.end();
}

void process_lines(SP &lines, SP &plines) {
	for (SP::iterator it = lines.begin(); it != lines.end(); ++it) {
		PPII cur = *it;
		SP::iterator adj = find_adj(plines, cur);
		if (adj == plines.end()) {
			plines.insert(cur);
		} else {
			PPII adjp = *adj;
			plines.erase(adj);
			plines.insert(join_adj(cur, adjp));
		}
	}
}

/* TRANSFORMACIE */
struct tparams {
	LD scale, angle, dx, dy;
};

tparams get_params(PPII a, PPII b) {
	tparams p;
	p.angle = atanl((LD) DY(a)/DX(a)) - atanl((LD) DY(b)/DX(b));
	p.scale = sqrtl(DX(b)*DX(b) + DY(b)*DY(b))
	        / sqrtl(DX(a)*DX(a) + DY(a)*DY(a));
	p.dx = b.X1 - a.X1;
	p.dy = b.Y1 - a.Y1;
	return p;
}

PPDD transform(PPII a, tparams p) {
	PPDD tmp = make_pair(
		make_pair(0, 0),
		make_pair(p.scale * DX(a), p.scale * DY(a))
	);
	PPDD res = make_pair(
		make_pair(0, 0),
		make_pair(tmp.X2 * cosl(p.angle) + tmp.Y2 * sinl(p.angle),
		         -tmp.X2 * sinl(p.angle) + tmp.Y2 * cosl(p.angle))
	);
	long double dx = a.X1 + p.dx;
	long double dy = a.Y1 + p.dy;	
	res.X1 += dx;
	res.Y1 += dy;
	res.X2 += dx;
	res.Y2 += dy;
	return res;
}

int main() {
	while (1) {
		SP tmp, lines1, lines2;
		if (!load_lines(tmp)) return 0;
		process_lines(tmp, lines1);
		tmp.clear();
		load_lines(tmp);
		process_lines(tmp, lines2);
		
		printf("lines1: %d\n", lines1.size());
		for (SP::iterator it = lines1.begin(); it != lines1.end(); ++it) {
			printf("  [%d %d] [%d %d]\n", it->X1, it->Y1, it->X2, it->Y2);
		}
		printf("lines2: %d\n", lines2.size());
		for (SP::iterator it = lines2.begin(); it != lines2.end(); ++it) {
			printf("  [%d %d] [%d %d]\n", it->X1, it->Y1, it->X2, it->Y2);
		}
		
		bool ok = false;
		if (lines1.size() == lines2.size()) {
			//for (SP::iterator it = lines2.begin(); it != lines2.end(); ++it) {
			SP::iterator it = lines2.begin();
			{
				tparams p = get_params(*(lines1.begin()), *it);
				printf("%Lf %Lf %Lf %Lf\n", p.scale, p.angle, p.dx, p.dy);
				ok = true;
				for (SP::iterator i = lines1.begin(); i != lines1.end(); ++i) {
					PPDD trans = transform(*i, p);
					printf("--> [%Lf %Lf] [%Lf %Lf]\n", trans.X1, trans.Y1, trans.X2, trans.Y2);
					
					// test celociselnosti
					if (fabsl(trans.X1 - roundl(trans.X1)) > EPS) { printf("ROUND\n"); ok = false; break; }
					if (fabsl(trans.Y1 - roundl(trans.Y1)) > EPS) { printf("ROUND\n"); ok = false; break; }
					if (fabsl(trans.X2 - roundl(trans.X2)) > EPS) { printf("ROUND\n"); ok = false; break; }
					if (fabsl(trans.Y2 - roundl(trans.Y2)) > EPS) { printf("ROUND\n"); ok = false; break; }
					// round
					PPII transformed = make_pair(
						make_pair(roundl(trans.X1), roundl(trans.Y1)),
						make_pair(roundl(trans.X2), roundl(trans.Y2))
					);
					printf("R-> [%d %d] [%d %d]\n", transformed.X1, transformed.Y1, transformed.X2, transformed.Y2);
					PPII opacna = make_pair(transformed.second, transformed.first);
					
					if (lines2.find(transformed) == lines2.end()
							&& lines2.find(opacna) == lines2.end()) {
						ok = false;
						break;
					}
				}
				if (ok) break;
			}
		}
		
		if (ok) {
			printf("YES\n");
		} else {
			printf("NO\n");
		}
	}
}
